#[repr(transparent)]pub struct RawKey(u64);Expand description
The key used in IdTypeMap, which is a combination of an Id and a TypeId.
This key can be used to remove or access values in the IdTypeMap without
knowledge of the TypeId T that is required for other accessors.
RawKeys make no guarantees about layout or their ability to be persisted.
They only produce deterministic results if they are used with the map
they were initially obtained from. Using them on other instances of IdTypeMap
may produce unexpected behavior.
Tuple Fields
0: u64Implementations